#[non_exhaustive]pub enum ConnError {
NoDisplay,
NoLogname,
Io(PathBuf, Error),
BadScreen(i32),
ServerNotFound,
X11(Error),
}Expand description
Error during establishing connection to the Sawfish server.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoDisplay
No display specified and DISPLAY environment variable not set.
NoLogname
LOGNAME environment variable not set.
This is relevant when connecting to Unix socket since without the login name socket name cannot be determined.
Io(PathBuf, Error)
An I/O error during establishing of the connection (e.g. Unix socket does not exist or user lacks permissions to access it).
BadScreen(i32)
Available on crate feature
experimental-xcb only.Invalid X11 display screen number.
ServerNotFound
Available on crate feature
experimental-xcb only.No Sawfish server found on display.
X11(Error)
Available on crate feature
experimental-xcb only.An X11 error during establishing of the connection.